
.. image:: https://img.shields.io/endpoint?url=https://gitlab.com/nannos/nannos/-/jobs/artifacts/master/file/logobadge.json?job=badge
  :target: https://gitlab.com/nannos/nannos/-/releases
  :alt: Release


.. image:: https://img.shields.io/gitlab/pipeline/nannos/nannos/master?logo=gitlab&labelColor=dedede&logoColor=ffffff&style=for-the-badge
  :target: https://gitlab.com/nannos/nannos/commits/master
  :alt: pipeline status


.. image:: https://img.shields.io/gitlab/coverage/nannos/nannos/master?logo=python&logoColor=e9d672&style=for-the-badge
 :target: https://gitlab.com/nannos/nannos/commits/master
 :alt: coverage report


.. image:: https://img.shields.io/badge/code%20style-black-dedede.svg?logo=python&logoColor=e9d672&style=for-the-badge
  :alt: Code style: black


.. image:: https://img.shields.io/badge/license-GPLv3-blue?color=dd7d54&logo=open-access&logoColor=dd7d54&style=for-the-badge
  :target: https://gitlab.com/nannos/nannos/-/blob/master/LICENCE.txt
  :alt: license



----------------------

.. image:: https://img.shields.io/pypi/v/nannos?color=blue&logo=pypi&logoColor=e9d672&style=for-the-badge
  :target: https://pypi.org/project/nannos/
  :alt: PyPI


.. image:: https://img.shields.io/pypi/dm/nannos?logo=pypi&logoColor=e9d672&style=for-the-badge
  :alt: PyPI - Downloads


.. image:: https://img.shields.io/pypi/status/nannos?logo=pypi&logoColor=e9d672&style=for-the-badge
  :alt: PyPI - Status


.. .. image:: https://img.shields.io/codeclimate/maintainability/benvial/nannos?logo=code-climate&style=for-the-badge
..    :target: https://codeclimate.com/github/benvial/nannos
..    :alt: Code Climate maintainability


.. image:: https://img.shields.io/badge/DOI-10.5281/zenodo.6490098-dd7d54?logo=google-scholar&logoColor=dd7d54&style=for-the-badge
 :target: https://doi.org/10.5281/zenodo.6490098


.. ------------------------------------------------------------------------------------------
..
..
.. .. image:: https://img.shields.io/conda/vn/conda-forge/nannos?logo=conda-forge&color=CD5C5C&logoColor=white&style=for-the-badge
..    :target: https://anaconda.org/conda-forge/nannos
..    :alt: Conda (channel only)
..
.. .. image:: https://img.shields.io/conda/dn/conda-forge/nannos?logo=conda-forge&logoColor=white&style=for-the-badge
..    :alt: Conda
..
.. .. image:: https://img.shields.io/conda/pn/conda-forge/nannos?logo=conda-forge&logoColor=white&style=for-the-badge
..    :alt: Conda


----------------------------

.. inclusion-marker-badges

=============================================================
nannos: Fourier Modal Method for multilayer metamaterials
=============================================================


.. inclusion-marker-install-start

Installation
============

From pypi
---------

The package is available on `pypi <https://pypi.org/project/nannos>`_.
To install, simply use:

.. code-block:: bash

  pip install nannos


From sources
-------------

Sources are available on `gitlab <https://gitlab.com/nannos/nannos>`_. First
clone the repository and install with ``pip``:

.. code-block:: bash

  git clone https://gitlab.com/nannos/nannos.git
  cd nannos
  pip install -e .


.. inclusion-marker-install-end


Documentation
=============

The reference documentation and examples can be found on the
`project website <https://nannos.gitlab.io>`_.


License
=======


.. inclusion-marker-license-start

This software is published under the `GPLv3 license <https://www.gnu.org/licenses/gpl-3.0.en.html>`_.


.. inclusion-marker-license-end
